Welcome to django-qanda’s documentation! — django-qanda 1.0 documentation

### Navigation

- index
- next |
- django-qanda 1.0 documentation »

# Welcome to django-qanda’s documentation!

Qanda is a simple FAQ app for Django projects.

Here are the main features:

- Published questions can be made public, restricted to logged-in users, or only visible to site staff.
- Topics are self-hiding depending on the access level of the questions they contain.
- Qanda installs with a fully working set of templates so you can start playing straight away.

You can get started with Installation

## Screenshots

Because everyone loves screenshots, here are the three default views that Qanda installs with...

Topic List

The topic list is ‘index’ page of the app. It shows both the available topics and a list of the most recently modified questions.

Topic Detail

Clicking into a particular topic, this page shows the available questions in that topic with brief information such as the modification date and an extract of the published answer.

Question Detail

Diving into a chosen question you can read the answer in full. This view also provides quick links to other questions in the same topic.

Contents:

- Installation
  - Distribute & Pip
  - Get the code
  - Configuring your project

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- django-qanda 1.0 documentation »